%define major_version 24
%define version %{major_version}.0.5
%define rel 1

%define prerel %{nil}
%define name_root nextcloud
%define oname server

%if "%{prerel}" != "%{nil}"
%define lc_prerel %(echo %{prerel} | tr "A-Z" "a-z")
%define release %mkrel 1.%{lc_prerel}.%{rel}
%else
%define release %mkrel %{rel}
%endif

# exclude PHP dependencies as long as their usage is not proven
%define __requires_exclude_from ^%{_datadir}/.*$
%define __jar_repack %{nil}

Summary:      Open personal cloud
Name:         %{name_root}
Version:      %{version}
Release:      %{release}
License:      AGPLv3
Group:        Networking/WWW 
Url:          http://nextcloud.com
Source0:      https://download.nextcloud.com/server/releases/server-%{version}%{?prerel}.tar.gz
Source1:      %{name_root}-httpd.conf
Source2:      %{name_root}-httpd.inc
Source4:      %{name_root}-mysql.txt
Source5:      %{name_root}-postgresql.txt
Source7:      %{name_root}-config.php
Source8:      %{name_root}-fpm.conf
# Systemd timer for background jobs
Source9:       %{name}-systemd-timer.service
Source10:       %{name}-systemd-timer.timer
Requires:     php-webinterface >= 3:8.0.0
Requires:     php-curl >= 3:8.0.0
Requires:     php-dom  >= 3:8.0.0
Requires:     php-exif >= 3:8.0.0
Requires:     php-fileinfo >= 3:8.0.0
Requires:     php-gd >= 3:8.0.0
Requires:     php-iconv >= 3:8.0.0
Requires:     php-imagick 
Recommends:   php-intl >= 3:8.0.0
Requires:     php-json >= 3:8.0.0
Requires:     php-ldap >= 3:8.0.0
Requires:     php-mbstring >= 3:8.0.0
Requires:     php-openssl >= 3:8.0.0
Requires:     php-pcre >= 3:8.0.0
Recommends:   php-pcntl >= 3:8.0.0
Requires:     php-pdo >= 3:8.0.0
Requires:     php-session >= 3:8.0.0
Requires:     php-simplexml >= 3:8.0.0
Requires:     php-xmlwriter >= 3:8.0.0
Requires:     php-xmlreader
Requires:     php-zip >= 3:8.0.0
Requires:     php-filter >= 3:8.0.0
Requires:     %{name}-database = %{version}-%{release}
Requires:     openssl >= 1.0.2f
Obsoletes:    nextcloud17 <= 18.0.0.0
Obsoletes:    nextcloud18 < %{version}
BuildArch:    noarch

%description
A personal cloud server which runs on you personal server 
and enables accessing your data from everywhere and sharing 
with other people.

%package mysql
Summary:    MySQL database support for NextCloud
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
# From getSupportedDatabases, mysql => pdo, mysql
Requires:   php-pdo_mysql >= 3:8.0.0

%description mysql
This package ensures the necessary dependencies are in place for NextCloud to
work with MySQL / MariaDB databases. It does not require a MySQL / MariaDB
server to be installed, as you may well wish to use a remote database
server.
If you want the database to be on the same system as NextCloud itself, you must
also install and enable a MySQL / MariaDB server package. See README.mysql for
more details.

%package postgresql
Summary:    PostgreSQL database support for NextCloud
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
# From getSupportedDatabases, pgsql => function, pg_connect
Requires:   php-pdo_pgsql >= 3:8.0.0

%description postgresql
This package ensures the necessary dependencies are in place for NextCloud to
work with a PostgreSQL database. It does not require the PostgreSQL server
package to be installed, as you may well wish to use a remote database
server.
If you want the database to be on the same system as NextCloud itself, you must
also install and enable the PostgreSQL server package. See README.postgresql
for more details.

%package sqlite
Summary:    SQLite 3 database support for NextCloud
Provides:   %{name}-database = %{version}-%{release}
Requires:   %{name} = %{version}-%{release}
# From getSupportedDatabases, pgsql => class, SQLite3
Requires:   php-pdo_sqlite >= 3:8.0.0
Requires:   php-pcre  >= 3:8.0.0

%description sqlite
This package ensures the necessary dependencies are in place for NextCloud to
work with an SQLite 3 database stored on the local system.

%prep
%setup -q -n server-%{version}
cp %{SOURCE4} README.mysql
cp %{SOURCE5} README.postgresql
# drop upstream update notification app
rm -rf apps/updatenotification
# also remove the actual updater
rm -rf updater

%install
install -d -m 755 %{buildroot}%{_datadir}/%{name_root}
# create nextcloud datadir
install -d -m 755 %{buildroot}%{_localstatedir}/lib/%{name_root}/data
# create writable app dir for appstore
install -d -m 755 %{buildroot}%{_localstatedir}/lib/%{name_root}/apps
# create nextcloud sysconfdir
install -d -m 755 %{buildroot}%{_sysconfdir}/%{name_root}

# install content
for d in $(find . -mindepth 1 -maxdepth 1 -type d | grep -v config); do
    cp -a "$d" %{buildroot}%{_datadir}/%{name_root}
done

for f in {*.php,*.html,occ,robots.txt}; do
    install -p -m 644 "$f" %{buildroot}%{_datadir}/%{name_root}
done

# occ should be executable
install -pm 755 occ %{buildroot}%{_datadir}/%{name}

# symlink config dir
ln -sf %{_sysconfdir}/%{name_root} %{buildroot}%{_datadir}/%{name_root}/config

# nextcloud looks for ca-bundle.crt in config dir
ln -sf %{_sysconfdir}/pki/tls/certs/ca-bundle.crt %{buildroot}%{_sysconfdir}/%{name_root}/ca-bundle.crt

# set default config
install -p -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/%{name_root}/config.php

install -D -m 644 %{SOURCE1} %{buildroot}%{webappconfdir}/%{name_root}.conf
install -D -m 644 %{SOURCE2} %{buildroot}%{webappconfdir}/%{name_root}.inc
install -D -m 644 %{SOURCE8} %{buildroot}%{_sysconfdir}/php-fpm.d/%{name_root}.conf

cat > %{buildroot}%{_datadir}/%{name_root}/.htaccess <<EOF
# Version: %{version}
EOF

install -d -m 755 %{buildroot}%{_sysconfdir}/cron.d
cat > %{buildroot}%{_sysconfdir}/cron.d/%{name_root} <<EOF
# Run cron from to execute task even when no user connected
*/15 * * * * apache /usr/bin/php -f /usr/share/nextcloud/cron.php
EOF

# Install the systemd timer
install -Dpm 644 %{SOURCE9} %{buildroot}%{_unitdir}/nextcloud-cron.service
install -Dpm 644 %{SOURCE10} %{buildroot}%{_unitdir}/nextcloud-cron.timer

%pre
# on update from previous release, move data directory from
# %{_localstatedir}/lib/%{name} to %{_localstatedir}/lib/%{name}/data
if [ $1 -gt 1 ] ; then
    if [ -d %{_localstatedir}/lib/%{name_root}/ -a ! -d %{_localstatedir}/lib/%{name_root}/data ]; then
        mv %{_localstatedir}/lib/%{name_root} %{_localstatedir}/lib/%{name_root}.tmp
        mkdir %{_localstatedir}/lib/%{name_root}
        mv %{_localstatedir}/lib/%{name_root}.tmp %{_localstatedir}/lib/%{name_root}/data
    fi
fi

%post
touch '%{_sysconfdir}/%{name}/CAN_INSTALL'
/usr/bin/chown apache:apache '%{_sysconfdir}/%{name}/CAN_INSTALL'

%files
%doc AUTHORS config/config.sample.php

%dir %attr(-,apache,apache) %{_sysconfdir}/%{name_root}
%config(noreplace) %attr(0600,apache,apache) %{_sysconfdir}/%{name_root}/config.php
%{_sysconfdir}/%{name_root}/ca-bundle.crt

%{_datadir}/%{name_root}
%{_unitdir}/nextcloud-cron.service
%{_unitdir}/nextcloud-cron.timer

%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name_root}
%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name_root}/apps
%dir %attr(0750,apache,apache) %{_localstatedir}/lib/%{name_root}/data

%config(noreplace) %{webappconfdir}/nextcloud.conf
%config(noreplace) %{webappconfdir}/nextcloud.inc
%config(noreplace) %{_sysconfdir}/cron.d/%{name_root}
%config(noreplace) %{_sysconfdir}/php-fpm.d/%{name_root}.conf

%files mysql
%doc README.mysql

%files postgresql
%doc README.postgresql

%files sqlite


%changelog
* Wed Sep 14 2022 neoclust <neoclust> 24.0.5-1.mga8
+ Revision: 1888152
- New version 24.0.5
- New version 22.2.3
  Fix occ permissions
- New release 21.0.0

* Sat Jan 16 2021 neoclust <neoclust> 21.0.0-1.beta6.2.mga8
+ Revision: 1672101
- Fix 3rdparty
  Fix minimal deps
  Requires php8

* Thu Jan 14 2021 neoclust <neoclust> 21.0.0-1.beta6.1.mga8
+ Revision: 1671799
- New version 21.0.0beta6 ( php8 friendly)
- Revert back to version 20.0.1, will help to switch to 21.0.0 beta6

* Mon Dec 14 2020 joequant <joequant> 21.0.0-0.20201214.1.mga8
+ Revision: 1657078
- update nextcloud-install

* Mon Dec 14 2020 joequant <joequant> 21.0.0-0.20201210.1.mga8
+ Revision: 1656902
- replace files with install script

* Sun Dec 06 2020 joequant <joequant> 21.0.0-0.20201206.1.dev.gite41e2fe.mga8
+ Revision: 1653407
- update to nextcloud 21 so that it works with php8

* Mon Nov 16 2020 joequant <joequant> 20.0.1-2.mga8
+ Revision: 1646639
- Put in patch for nextcloud #23606

* Thu Nov 05 2020 joequant <joequant> 20.0.1-1.mga8
+ Revision: 1642839
- update to 20.0.1

* Mon Oct 26 2020 joequant <joequant> 19.0.4-2.mga8
+ Revision: 1639500
- fix up CAN_INSTALL
- move back to 19.0.4 for core/release

* Mon Oct 26 2020 joequant <joequant> 20.0.0-1.mga8
+ Revision: 1639498
- update to 20.0.0
- fix %%section
- add 20.0.0 to updates/testing

* Wed Oct 21 2020 joequant <joequant> 19.0.4-1.mga8
+ Revision: 1637419
- update to 19.0.4

* Wed Oct 07 2020 joequant <joequant> 19.0.3-1.mga8
+ Revision: 1632546
- update to 19.0.3

* Sat Jul 18 2020 joequant <joequant> 19.0.1-1.mga8
+ Revision: 1607144
- update to 19.0.1

* Mon Jun 08 2020 zezinho <zezinho> 19.0.0-1.mga8
+ Revision: 1590952
- new version 19.0.0 - remove upstreamed patches

* Mon Jun 08 2020 zezinho <zezinho> 18.0.5-2.mga8
+ Revision: 1590938
- no need to obsolete the same package name

* Sat Jun 06 2020 joequant <joequant> 18.0.5-1.mga8
+ Revision: 1590793
- update to 18.0.5

* Sun Apr 26 2020 joequant <joequant> 18.0.4-1.mga8
+ Revision: 1572243
- update to 18.0.4

* Mon Mar 30 2020 joequant <joequant> 18.0.3-5.mga8
+ Revision: 1562464
- remove major release

* Sat Mar 14 2020 joequant <joequant> 18.0.2-1.mga8
+ Revision: 1556269
- upgrade to 18.0.2

* Thu Feb 20 2020 zezinho <zezinho> 16.0.8-2.mga8
+ Revision: 1547324
- new version

* Mon Feb 17 2020 umeabot <umeabot> 16.0.6-2.mga8
+ Revision: 1537799
- Mageia 8 Mass Rebuild

* Mon Nov 11 2019 zezinho <zezinho> 16.0.6-1.mga8
+ Revision: 1459194
- upgrade to latest 16 dot release in cauldron to prepare backport for MGA7

* Tue Oct 08 2019 zezinho <zezinho> 15.0.12-1.mga8
+ Revision: 1450614
- new bugfix version 15.0.12
- add recommend on php-imagick as it is suggested by the admin check

* Tue Aug 20 2019 zezinho <zezinho> 15.0.11-1.mga8
+ Revision: 1430465
- new bugfix version 15.0.11

* Sun Apr 07 2019 kekepower <kekepower> 15.0.6-1.mga7
+ Revision: 1386708
- Update to version 15.0.6

* Tue Mar 26 2019 zezinho <zezinho> 15.0.5-1.mga7
+ Revision: 1380415
- new bugfix version 15.0.5

* Sat Feb 23 2019 guillomovitch <guillomovitch> 15.0.4-1.mga7
+ Revision: 1369562
- new version 15.0.4

* Wed Dec 12 2018 zezinho <zezinho> 15.0.0-1.mga7
+ Revision: 1340852
- new version 15.0.0

* Wed Dec 12 2018 zezinho <zezinho> 14.0.4-1.mga7
+ Revision: 1340645
- new version 14.4.0 requiring php 7

* Thu Nov 22 2018 kekepower <kekepower> 13.0.8-1.mga7
+ Revision: 1333336
- Update to version 13.0.8

* Tue Nov 06 2018 kekepower <kekepower> 13.0.7-1.mga7
+ Revision: 1328655
- Update to version 13.0.7

* Thu Sep 20 2018 umeabot <umeabot> 13.0.6-2.mga7
+ Revision: 1280140
- Mageia 7 Mass Rebuild

* Fri Sep 07 2018 zezinho <zezinho> 13.0.6-1.mga7
+ Revision: 1257733
- new version 13.0.6

* Thu Aug 02 2018 guillomovitch <guillomovitch> 13.0.5-1.mga7
+ Revision: 1246963
- new version 13.0.5

* Tue Jun 26 2018 zezinho <zezinho> 13.0.4-1.mga7
+ Revision: 1239782
- new version 13.0.4

* Fri Apr 27 2018 zezinho <zezinho> 13.0.1-2.mga7
+ Revision: 1222889
- sql requires now pdo

* Sat Apr 14 2018 blino <blino> 13.0.1-1.mga7
+ Revision: 1218538
- 13.0.1

* Fri Jan 05 2018 neoclust <neoclust> 13.0.0-1.beta4.1.mga7
+ Revision: 1190552
- New version 13.0.0 beta4

* Tue Jan 02 2018 guillomovitch <guillomovitch> 12.0.4-1.mga7
+ Revision: 1189189
- new version 12.0.4

* Mon Dec 25 2017 zezinho <zezinho> 12.0.3-3.mga7
+ Revision: 1184611
- recommend pcntl php extension as it is hinted by occ command

* Mon Dec 25 2017 zezinho <zezinho> 12.0.3-2.mga7
+ Revision: 1184605
- add README.urpmi file explaining upgrade

* Tue Sep 26 2017 guillomovitch <guillomovitch> 12.0.3-1.mga7
+ Revision: 1159915
- new version 12.0.3

* Wed Sep 13 2017 guillomovitch <guillomovitch> 12.0.2-1.mga7
+ Revision: 1153655
- new version 12.0.2
- use a better group
- split stuff related to databases in distinct subpackages
- install appstore-downloaded apps under /var/lib/nextcloud/apps
- cherry-pick a few fedora patches
- better apache configuration
- do not obsolete owncloud, or try to migrate automatically data from it
+ zezinho <zezinho>
- recommends php-pcntl as it is told when running the occ cli command on files:scan

* Tue May 16 2017 luigiwalser <luigiwalser> 11.0.3-1.mga6
+ Revision: 1102246
- 11.0.3

* Sun Mar 05 2017 neoclust <neoclust> 11.0.2-1.mga6
+ Revision: 1088905
- New version 11.0.2

* Sun Jan 01 2017 luigiwalser <luigiwalser> 10.0.2-1.mga6
+ Revision: 1078936
- 10.0.2

* Sun Dec 11 2016 ngompa <ngompa> 10.0.1-3.mga6
+ Revision: 1074254
- Remove unneeded %%pretrans

* Mon Oct 24 2016 neoclust <neoclust> 10.0.1-2.mga6
+ Revision: 1063374
- Requires php-opcache

* Wed Oct 12 2016 zezinho <zezinho> 10.0.1-1.mga6
+ Revision: 1060534
- new version now in tar.bz2

* Tue Sep 13 2016 neoclust <neoclust> 10.0.0-1.mga6
+ Revision: 1052529
- New version 10.0.0

* Wed Aug 10 2016 neoclust <neoclust> 9.0.53-1.mga6
+ Revision: 1045479
- Add owncloud.conf for compatibility
- New version 9.0.53

* Mon Jul 04 2016 neoclust <neoclust> 9.0.50-2.mga6
+ Revision: 1038684
- Fix nextcloud URL

* Sun Jun 19 2016 neoclust <neoclust> 9.0.50-1.mga6
+ Revision: 1036847
- imported package nextcloud

